import requests
import time
from typing import Any, Dict, Optional
from .types import TaskResponse, AccountInfo

class MyDisctClient:
    def __init__(self, apiKey: str, baseURL: str = 'https://solver-api.mydisct.com'):
        if not apiKey:
            raise ValueError('API key is required')
        self.apiKey = apiKey
        self.baseURL = baseURL
        self.session = requests.Session()
        self.session.headers.update({
            'Content-Type': 'application/json',
            'apikey': self.apiKey
        })
    
    def createTask(self, captchaType: str, metadata: Dict[str, Any], payload: Dict[str, Any] = None) -> str:
        if payload is None:
            payload = {}
        
        response = self.session.post(
            f'{self.baseURL}/createTask',
            json={
                'auth': {'token': self.apiKey},
                'context': {'source': 'python-sdk', 'version': '1.0.0'},
                'captcha': {
                    'type': captchaType,
                    'metadata': metadata,
                    'payload': payload
                }
            }
        )
        
        data = response.json()
        
        if not data.get('success'):
            error_message = data.get('error', {}).get('message', 'Failed to create task')
            raise Exception(error_message)
        
        return data['task']['id']
    
    def fetchResult(self, taskId: str) -> TaskResponse:
        response = self.session.post(
            f'{self.baseURL}/fetchResult',
            json={'taskId': taskId}
        )
        return response.json()
    
    def waitForResult(self, taskId: str, pollingInterval: int = 5000, timeout: int = 120000) -> str:
        startTime = time.time() * 1000
        pollingIntervalSeconds = pollingInterval / 1000
        
        while (time.time() * 1000 - startTime) < timeout:
            result = self.fetchResult(taskId)
            
            if result['task']['status'] == 'completed':
                token = result.get('task', {}).get('result', {}).get('token')
                if not token:
                    raise Exception('Task completed but no token received')
                return token
            
            if result['task']['status'] == 'failed':
                error_message = result.get('error', {}).get('message', 'Task failed')
                raise Exception(error_message)
            
            time.sleep(pollingIntervalSeconds)
        
        raise Exception('Task timeout exceeded')
    
    def getBalance(self) -> float:
        response = self.session.get(f'{self.baseURL}/balance')
        data = response.json()
        
        if not data.get('success'):
            error_message = data.get('error', {}).get('message', 'Failed to get balance')
            raise Exception(error_message)
        
        return data['balance']['amount']
    
    def getAccountInfo(self) -> AccountInfo:
        response = self.session.get(f'{self.baseURL}/accountInfo')
        data = response.json()
        
        if not data.get('success'):
            error_message = data.get('error', {}).get('message', 'Failed to get account info')
            raise Exception(error_message)
        
        return data['account']



from .client import MyDisctClient
from .types import (
    RecaptchaV2Options, RecaptchaV3Options, RecaptchaV2EnterpriseOptions,
    RecaptchaV3EnterpriseOptions, HCaptchaOptions, HCaptchaEnterpriseOptions,
    CloudflareTurnstileOptions, CloudflareTurnstileManagedOptions,
    CloudflareChallengeOptions, FunCaptchaOptions, GeeTestV4Options,
    MTCaptchaOptions, LeminCaptchaOptions, FriendlyCaptchaOptions,
    DataDomeOptions, AltchaOptions, TencentCaptchaOptions,
    NetEaseCaptchaOptions, FaucetPayCaptchaOptions, CaptchaFoxOptions,
    AWSCaptchaOptions, TextCaptchaImageOptions, RecaptchaImageOptions,
    HCaptchaImageOptions, FunCaptchaImageOptions, GeeTestV3ImageOptions,
    GeeTestV4ImageOptions, RotateImageOptions, SlideCaptchaImageOptions,
    ClickCaptchaImageOptions, GridCaptchaImageOptions, MultiSelectImageOptions,
    DragCaptchaImageOptions, MTCaptchaImageOptions, LeminCaptchaImageOptions,
    DataDomeCaptchaImageOptions, CaptchaFoxImageOptions, BinanceImageOptions,
    BLSImageOptions, TikTokImageOptions, ShopeeImageOptions,
    TemuCaptchaImageOptions, TencentImageOptions, AWSWAFImageOptions,
    ProsopoImageOptions, FaucetPayImageOptions, AccountInfo
)
from typing import Optional

class MyDisctSolver:
    def __init__(self, apiKey: str, baseURL: Optional[str] = None):
        if baseURL is None:
            self.client = MyDisctClient(apiKey)
        else:
            self.client = MyDisctClient(apiKey, baseURL)
    
    def recaptchaV2Token(self, options: RecaptchaV2Options) -> str:
        taskId = self.client.createTask(
            'RECAPTCHA_V2_TOKEN',
            {
                'siteUrl': options['siteUrl'],
                'siteKey': options['siteKey']
            },
            {
                'invisible': options.get('invisible'),
                'userAgent': options.get('userAgent'),
                'cookies': options.get('cookies'),
                'domain': options.get('domain'),
                'proxy': options.get('proxy')
            }
        )
        return self.client.waitForResult(taskId)
    
    def recaptchaV3Token(self, options: RecaptchaV3Options) -> str:
        taskId = self.client.createTask(
            'RECAPTCHA_V3_TOKEN',
            {
                'siteUrl': options['siteUrl'],
                'siteKey': options['siteKey']
            },
            {
                'recaptchaAction': options.get('recaptchaAction', 'verify'),
                'userAgent': options.get('userAgent'),
                'cookies': options.get('cookies'),
                'domain': options.get('domain'),
                'proxy': options.get('proxy')
            }
        )
        return self.client.waitForResult(taskId)
    
    def recaptchaV2EnterpriseToken(self, options: RecaptchaV2EnterpriseOptions) -> str:
        taskId = self.client.createTask(
            'RECAPTCHA_V2_ENTERPRISE_TOKEN',
            {
                'siteUrl': options['siteUrl'],
                'siteKey': options['siteKey']
            },
            {
                'sValue': options.get('sValue'),
                'userAgent': options.get('userAgent'),
                'cookies': options.get('cookies'),
                'proxy': options.get('proxy')
            }
        )
        return self.client.waitForResult(taskId)
    
    def recaptchaV3EnterpriseToken(self, options: RecaptchaV3EnterpriseOptions) -> str:
        taskId = self.client.createTask(
            'RECAPTCHA_V3_ENTERPRISE_TOKEN',
            {
                'siteUrl': options['siteUrl'],
                'siteKey': options['siteKey']
            },
            {
                'recaptchaAction': options.get('recaptchaAction', 'verify'),
                'sValue': options.get('sValue'),
                'userAgent': options.get('userAgent'),
                'cookies': options.get('cookies'),
                'proxy': options.get('proxy')
            }
        )
        return self.client.waitForResult(taskId)
    
    def hCaptchaToken(self, options: HCaptchaOptions) -> str:
        taskId = self.client.createTask(
            'HCAPTCHA_TOKEN',
            {
                'siteUrl': options['siteUrl'],
                'siteKey': options['siteKey']
            },
            {
                'invisible': options.get('invisible'),
                'rqdata': options.get('rqdata'),
                'userAgent': options.get('userAgent'),
                'proxy': options.get('proxy')
            }
        )
        return self.client.waitForResult(taskId)
    
    def hCaptchaEnterpriseToken(self, options: HCaptchaEnterpriseOptions) -> str:
        taskId = self.client.createTask(
            'HCAPTCHA_ENTERPRISE_TOKEN',
            {
                'siteUrl': options['siteUrl'],
                'siteKey': options['siteKey'],
                'domain': options.get('domain')
            },
            {
                'rqdata': options.get('rqdata'),
                'userAgent': options.get('userAgent'),
                'cookies': options.get('cookies'),
                'proxy': options.get('proxy')
            }
        )
        return self.client.waitForResult(taskId)
    
    def cloudflareTurnstileToken(self, options: CloudflareTurnstileOptions) -> str:
        taskId = self.client.createTask(
            'CLOUDFLARE_TURNSTILE_TOKEN',
            {
                'siteUrl': options['siteUrl'],
                'siteKey': options['siteKey']
            },
            {
                'proxy': options.get('proxy')
            }
        )
        return self.client.waitForResult(taskId)
    
    def cloudflareTurnstileManagedToken(self, options: CloudflareTurnstileManagedOptions) -> str:
        taskId = self.client.createTask(
            'CLOUDFLARE_TURNSTILE_MANAGED_TOKEN',
            {
                'siteUrl': options['siteUrl'],
                'siteKey': options['siteKey']
            },
            {
                'data': options['data'],
                'chlPageData': options['chlPageData'],
                'userAgent': options.get('userAgent'),
                'proxy': options.get('proxy')
            }
        )
        return self.client.waitForResult(taskId)
    
    def cloudflareChallengeToken(self, options: CloudflareChallengeOptions) -> str:
        taskId = self.client.createTask(
            'CLOUDFLARE_CHALLENGE_TOKEN',
            {
                'siteUrl': options['siteUrl']
            },
            {
                'userAgent': options.get('userAgent'),
                'proxy': options['proxy']
            }
        )
        return self.client.waitForResult(taskId, 5000, 180000)
    
    def funCaptchaToken(self, options: FunCaptchaOptions) -> str:
        taskId = self.client.createTask(
            'FUNCAPTCHA_TOKEN',
            {
                'siteUrl': options['siteUrl'],
                'siteKey': options['siteKey'],
                'subdomain': options.get('subdomain')
            },
            {
                'data': options.get('data'),
                'userAgent': options.get('userAgent'),
                'proxy': options.get('proxy')
            }
        )
        return self.client.waitForResult(taskId)
    
    def geeTestV4Token(self, options: GeeTestV4Options) -> str:
        taskId = self.client.createTask(
            'GEETEST_V4_TOKEN',
            {
                'siteUrl': options['siteUrl'],
                'siteKey': options['siteKey'],
                'apiServerSubdomain': options.get('apiServerSubdomain')
            },
            {
                'proxy': options['proxy']
            }
        )
        return self.client.waitForResult(taskId)
    
    def mtCaptchaToken(self, options: MTCaptchaOptions) -> str:
        taskId = self.client.createTask(
            'MTCAPTCHA_TOKEN',
            {
                'siteUrl': options['siteUrl'],
                'siteKey': options['siteKey']
            },
            {}
        )
        return self.client.waitForResult(taskId)
    
    def leminCaptchaToken(self, options: LeminCaptchaOptions) -> str:
        taskId = self.client.createTask(
            'LEMIN_CAPTCHA_TOKEN',
            {
                'siteUrl': options['siteUrl'],
                'siteKey': options['siteKey']
            },
            {
                'proxy': options.get('proxy')
            }
        )
        return self.client.waitForResult(taskId)
    
    def friendlyCaptchaToken(self, options: FriendlyCaptchaOptions) -> str:
        taskId = self.client.createTask(
            'FRIENDLY_CAPTCHA_TOKEN',
            {
                'siteUrl': options['siteUrl'],
                'siteKey': options['siteKey']
            },
            {
                'proxy': options.get('proxy')
            }
        )
        return self.client.waitForResult(taskId)
    
    def dataDomeToken(self, options: DataDomeOptions) -> str:
        taskId = self.client.createTask(
            'DATADOME_CAPTCHA_TOKEN',
            {
                'siteUrl': options['siteUrl'],
                'siteKey': options['siteKey']
            },
            {
                'userAgent': options.get('userAgent'),
                'proxy': options['proxy']
            }
        )
        return self.client.waitForResult(taskId)
    
    def altchaCaptchaToken(self, options: AltchaOptions) -> str:
        taskId = self.client.createTask(
            'ALTCHA_CAPTCHA_TOKEN',
            {
                'siteUrl': options['siteUrl'],
                'siteKey': ''
            },
            {
                'metadata': {
                    'challenge': options['challenge'],
                    'iterations': str(options['iterations']),
                    'salt': options['salt'],
                    'signature': options['signature']
                },
                'userAgent': options.get('userAgent'),
                'proxy': options.get('proxy')
            }
        )
        return self.client.waitForResult(taskId)
    
    def tencentCaptchaToken(self, options: TencentCaptchaOptions) -> str:
        taskId = self.client.createTask(
            'TENCENT_CAPTCHA_TOKEN',
            {
                'siteUrl': options['siteUrl'],
                'siteKey': options['siteKey']
            },
            {
                'proxy': options.get('proxy')
            }
        )
        return self.client.waitForResult(taskId)
    
    def netEaseCaptchaToken(self, options: NetEaseCaptchaOptions) -> str:
        taskId = self.client.createTask(
            'NETEASE_CAPTCHA_TOKEN',
            {
                'siteUrl': options['siteUrl'],
                'siteKey': options['siteKey'],
                'jsLibUrl': options.get('jsLibUrl'),
                'apiServerSubdomain': options.get('apiServerSubdomain')
            },
            {
                'userAgent': options.get('userAgent'),
                'captchaId': options.get('captchaId'),
                'captchaHash': options.get('captchaHash'),
                'captchaTimestamp': options.get('captchaTimestamp'),
                'proxy': options.get('proxy')
            }
        )
        return self.client.waitForResult(taskId)
    
    def faucetPayCaptchaToken(self, options: FaucetPayCaptchaOptions) -> str:
        taskId = self.client.createTask(
            'FAUCETPAY_CAPTCHA_TOKEN',
            {
                'siteUrl': options['siteUrl'],
                'siteKey': options['siteKey']
            },
            {
                'userAgent': options.get('userAgent'),
                'proxy': options.get('proxy')
            }
        )
        return self.client.waitForResult(taskId)
    
    def captchaFoxToken(self, options: CaptchaFoxOptions) -> str:
        taskId = self.client.createTask(
            'CAPTCHAFOX_TOKEN',
            {
                'siteUrl': options['siteUrl'],
                'siteKey': options['siteKey']
            },
            {
                'userAgent': options.get('userAgent'),
                'proxy': options.get('proxy')
            }
        )
        return self.client.waitForResult(taskId)
    
    def awsCaptchaToken(self, options: AWSCaptchaOptions) -> str:
        taskId = self.client.createTask(
            'AWS_CAPTCHA_TOKEN',
            {
                'siteUrl': options['siteUrl'],
                'siteKey': options['siteKey']
            },
            {
                'context': options.get('context'),
                'proxy': options.get('proxy')
            }
        )
        return self.client.waitForResult(taskId)
    
    def getBalance(self) -> float:
        return self.client.getBalance()
    
    def getAccountInfo(self) -> AccountInfo:
        return self.client.getAccountInfo()
    
    def textCaptchaImage(self, options: TextCaptchaImageOptions) -> str:
        taskId = self.client.createTask(
            'TEXT_CAPTCHA_IMAGE',
            {
                'siteUrl': options['siteUrl']
            },
            {
                'images': options['images'],
                'questionType': options.get('questionType', 'text'),
                'caseSensitive': options.get('caseSensitive'),
                'numeric': options.get('numeric'),
                'minLength': options.get('minLength'),
                'maxLength': options.get('maxLength'),
                'referenceImages': options.get('referenceImages', [])
            }
        )
        return self.client.waitForResult(taskId)
    
    def recaptchaImage(self, options: RecaptchaImageOptions) -> str:
        taskId = self.client.createTask(
            'RECAPTCHA_IMAGE',
            {
                'siteUrl': options['siteUrl']
            },
            {
                'images': options['images'],
                'question': options['question'],
                'questionType': options['questionType']
            }
        )
        return self.client.waitForResult(taskId)
    
    def hCaptchaImage(self, options: HCaptchaImageOptions) -> str:
        taskId = self.client.createTask(
            'HCAPTCHA_IMAGE',
            {
                'siteUrl': options['siteUrl']
            },
            {
                'images': options['images'],
                'question': options['question']
            }
        )
        return self.client.waitForResult(taskId)
    
    def funCaptchaImage(self, options: FunCaptchaImageOptions) -> str:
        taskId = self.client.createTask(
            'FUNCAPTCHA_IMAGE',
            {
                'siteUrl': options['siteUrl']
            },
            {
                'images': options['images'],
                'question': options['question']
            }
        )
        return self.client.waitForResult(taskId)
    
    def geeTestV3Image(self, options: GeeTestV3ImageOptions) -> str:
        taskId = self.client.createTask(
            'GEETEST_V3_IMAGE',
            {
                'siteUrl': options['siteUrl']
            },
            {
                'images': options['images'],
                'question': options['question']
            }
        )
        return self.client.waitForResult(taskId)
    
    def geeTestV4Image(self, options: GeeTestV4ImageOptions) -> str:
        taskId = self.client.createTask(
            'GEETEST_V4_IMAGE',
            {
                'siteUrl': options['siteUrl']
            },
            {
                'images': options['images'],
                'question': options['question']
            }
        )
        return self.client.waitForResult(taskId)
    
    def rotateImage(self, options: RotateImageOptions) -> str:
        taskId = self.client.createTask(
            'ROTATE_IMAGE',
            {
                'siteUrl': options['siteUrl']
            },
            {
                'images': options['images'],
                'question': options.get('question'),
                'angle': options.get('angle'),
                'referenceImages': options.get('referenceImages', [])
            }
        )
        return self.client.waitForResult(taskId)
    
    def slideCaptchaImage(self, options: SlideCaptchaImageOptions) -> str:
        taskId = self.client.createTask(
            'SLIDE_CAPTCHA_IMAGE',
            {
                'siteUrl': options['siteUrl']
            },
            {
                'images': options['images'],
                'question': options.get('question')
            }
        )
        return self.client.waitForResult(taskId)
    
    def clickCaptchaImage(self, options: ClickCaptchaImageOptions) -> str:
        taskId = self.client.createTask(
            'CLICK_CAPTCHA_IMAGE',
            {
                'siteUrl': options['siteUrl']
            },
            {
                'images': options['images'],
                'question': options['question'],
                'questionType': options.get('questionType', 'click'),
                'referenceImages': options.get('referenceImages', [])
            }
        )
        return self.client.waitForResult(taskId)
    
    def gridCaptchaImage(self, options: GridCaptchaImageOptions) -> str:
        taskId = self.client.createTask(
            'GRID_CAPTCHA_IMAGE',
            {
                'siteUrl': options['siteUrl']
            },
            {
                'images': options['images'],
                'question': options['question'],
                'rows': options.get('rows'),
                'columns': options.get('columns')
            }
        )
        return self.client.waitForResult(taskId)
    
    def multiSelectImage(self, options: MultiSelectImageOptions) -> str:
        taskId = self.client.createTask(
            'MULTI_SELECT_CAPTCHA_IMAGE',
            {
                'siteUrl': options['siteUrl']
            },
            {
                'images': options['images'],
                'question': options['question'],
                'referenceImages': options.get('referenceImages', [])
            }
        )
        return self.client.waitForResult(taskId)
    
    def dragCaptchaImage(self, options: DragCaptchaImageOptions) -> str:
        taskId = self.client.createTask(
            'DRAG_CAPTCHA_IMAGE',
            {
                'siteUrl': options['siteUrl']
            },
            {
                'images': options['images'],
                'question': options['question'],
                'questionType': options.get('questionType', 'drag'),
                'referenceImages': options.get('referenceImages', [])
            }
        )
        return self.client.waitForResult(taskId)
    
    def mtCaptchaImage(self, options: MTCaptchaImageOptions) -> str:
        taskId = self.client.createTask(
            'MTCAPTCHA_IMAGE',
            {
                'siteUrl': options['siteUrl']
            },
            {
                'images': options['images'],
                'module': options.get('module', 'mtcaptcha'),
                'maxLength': options.get('maxLength', 5)
            }
        )
        return self.client.waitForResult(taskId)
    
    def leminCaptchaImage(self, options: LeminCaptchaImageOptions) -> str:
        taskId = self.client.createTask(
            'LEMIN_CAPTCHA_IMAGE',
            {
                'siteUrl': options['siteUrl']
            },
            {
                'images': options['images'],
                'question': options['question']
            }
        )
        return self.client.waitForResult(taskId)
    
    def dataDomeCaptchaImage(self, options: DataDomeCaptchaImageOptions) -> str:
        taskId = self.client.createTask(
            'DATADOME_CAPTCHA_IMAGE',
            {
                'siteUrl': options['siteUrl']
            },
            {
                'images': options['images'],
                'question': options.get('question')
            }
        )
        return self.client.waitForResult(taskId)
    
    def captchaFoxImage(self, options: CaptchaFoxImageOptions) -> str:
        taskId = self.client.createTask(
            'CAPTCHAFOX_IMAGE',
            {
                'siteUrl': options['siteUrl']
            },
            {
                'images': options['images'],
                'question': options['question'],
                'questionType': options.get('questionType'),
                'referenceImages': options.get('referenceImages', [])
            }
        )
        return self.client.waitForResult(taskId)
    
    def binanceImage(self, options: BinanceImageOptions) -> str:
        taskId = self.client.createTask(
            'BINANCE_IMAGE',
            {
                'siteUrl': options['siteUrl']
            },
            {
                'images': options['images'],
                'question': options['question'],
                'questionType': options['questionType'],
                'referenceImages': options.get('referenceImages', [])
            }
        )
        return self.client.waitForResult(taskId)
    
    def blsImage(self, options: BLSImageOptions) -> str:
        taskId = self.client.createTask(
            'BLS_IMAGE',
            {
                'siteUrl': options['siteUrl']
            },
            {
                'images': options['images'],
                'question': options['question']
            }
        )
        return self.client.waitForResult(taskId)
    
    def tikTokImage(self, options: TikTokImageOptions) -> str:
        taskId = self.client.createTask(
            'TIKTOK_IMAGE',
            {
                'siteUrl': options['siteUrl']
            },
            {
                'images': options['images'],
                'question': options['question']
            }
        )
        return self.client.waitForResult(taskId)
    
    def shopeeImage(self, options: ShopeeImageOptions) -> str:
        taskId = self.client.createTask(
            'SHOPEE_IMAGE',
            {
                'siteUrl': options['siteUrl']
            },
            {
                'images': options['images'],
                'question': options['question']
            }
        )
        return self.client.waitForResult(taskId)
    
    def temuCaptchaImage(self, options: TemuCaptchaImageOptions) -> str:
        taskId = self.client.createTask(
            'TEMU_CAPTCHA_IMAGE',
            {
                'siteUrl': options['siteUrl']
            },
            {
                'images': options['images']
            }
        )
        return self.client.waitForResult(taskId)
    
    def tencentImage(self, options: TencentImageOptions) -> str:
        taskId = self.client.createTask(
            'TENCENT_IMAGE',
            {
                'siteUrl': options['siteUrl']
            },
            {
                'images': options['images'],
                'question': options['question']
            }
        )
        return self.client.waitForResult(taskId)
    
    def awsWAFImage(self, options: AWSWAFImageOptions) -> str:
        taskId = self.client.createTask(
            'AWS_WAF_IMAGE',
            {
                'siteUrl': options['siteUrl']
            },
            {
                'images': options['images'],
                'question': options['question']
            }
        )
        return self.client.waitForResult(taskId)
    
    def prosopoImage(self, options: ProsopoImageOptions) -> str:
        taskId = self.client.createTask(
            'PROSOPO_IMAGE',
            {
                'siteUrl': options['siteUrl']
            },
            {
                'images': options['images'],
                'question': options['question']
            }
        )
        return self.client.waitForResult(taskId)
    
    def faucetPayImage(self, options: FaucetPayImageOptions) -> str:
        taskId = self.client.createTask(
            'FAUCETPAY_IMAGE',
            {
                'siteUrl': options['siteUrl']
            },
            {
                'images': options['images'],
                'question': options['question']
            }
        )
        return self.client.waitForResult(taskId)



from typing import TypedDict, Optional, List, Literal, Any, Dict

class ProxyConfig(TypedDict, total=False):
    protocol: Literal['http', 'https', 'socks4', 'socks5']
    host: str
    port: int
    username: Optional[str]
    password: Optional[str]

class Cookie(TypedDict, total=False):
    name: str
    value: str
    domain: str
    path: Optional[str]

class TaskResult(TypedDict, total=False):
    token: str
    timestamp: Optional[str]

class Task(TypedDict, total=False):
    id: str
    status: Literal['processing', 'completed', 'failed']
    result: Optional[TaskResult]

class Error(TypedDict):
    code: str
    message: str

class TaskResponse(TypedDict, total=False):
    success: bool
    service: str
    message: str
    task: Task
    error: Optional[Error]

class AccountInfo(TypedDict):
    email: str
    username: str
    balance: float
    currency: str

class RecaptchaV2Options(TypedDict, total=False):
    siteUrl: str
    siteKey: str
    invisible: Optional[bool]
    userAgent: Optional[str]
    cookies: Optional[List[Cookie]]
    domain: Optional[str]
    proxy: Optional[ProxyConfig]

class RecaptchaV3Options(TypedDict, total=False):
    siteUrl: str
    siteKey: str
    recaptchaAction: Optional[str]
    userAgent: Optional[str]
    cookies: Optional[List[Cookie]]
    domain: Optional[str]
    proxy: Optional[ProxyConfig]

class RecaptchaV2EnterpriseOptions(TypedDict, total=False):
    siteUrl: str
    siteKey: str
    sValue: Optional[str]
    userAgent: Optional[str]
    cookies: Optional[List[Cookie]]
    proxy: Optional[ProxyConfig]

class RecaptchaV3EnterpriseOptions(TypedDict, total=False):
    siteUrl: str
    siteKey: str
    recaptchaAction: Optional[str]
    sValue: Optional[str]
    userAgent: Optional[str]
    cookies: Optional[List[Cookie]]
    proxy: Optional[ProxyConfig]

class HCaptchaOptions(TypedDict, total=False):
    siteUrl: str
    siteKey: str
    invisible: Optional[bool]
    rqdata: Optional[str]
    userAgent: Optional[str]
    proxy: Optional[ProxyConfig]

class HCaptchaEnterpriseOptions(TypedDict, total=False):
    siteUrl: str
    siteKey: str
    domain: Optional[str]
    rqdata: Optional[str]
    userAgent: Optional[str]
    cookies: Optional[List[Cookie]]
    proxy: Optional[ProxyConfig]

class CloudflareTurnstileOptions(TypedDict, total=False):
    siteUrl: str
    siteKey: str
    proxy: Optional[ProxyConfig]

class CloudflareTurnstileManagedOptions(TypedDict, total=False):
    siteUrl: str
    siteKey: str
    data: str
    chlPageData: str
    userAgent: Optional[str]
    proxy: Optional[ProxyConfig]

class CloudflareChallengeOptions(TypedDict, total=False):
    siteUrl: str
    userAgent: Optional[str]
    proxy: ProxyConfig

class FunCaptchaOptions(TypedDict, total=False):
    siteUrl: str
    siteKey: str
    subdomain: Optional[str]
    data: Optional[str]
    userAgent: Optional[str]
    proxy: Optional[ProxyConfig]

class GeeTestV4Options(TypedDict, total=False):
    siteUrl: str
    siteKey: str
    apiServerSubdomain: Optional[str]
    proxy: ProxyConfig

class MTCaptchaOptions(TypedDict):
    siteUrl: str
    siteKey: str

class LeminCaptchaOptions(TypedDict, total=False):
    siteUrl: str
    siteKey: str
    proxy: Optional[ProxyConfig]

class FriendlyCaptchaOptions(TypedDict, total=False):
    siteUrl: str
    siteKey: str
    proxy: Optional[ProxyConfig]

class DataDomeOptions(TypedDict, total=False):
    siteUrl: str
    siteKey: str
    userAgent: Optional[str]
    proxy: ProxyConfig

class AltchaOptions(TypedDict, total=False):
    siteUrl: str
    challenge: str
    iterations: int
    salt: str
    signature: str
    userAgent: Optional[str]
    proxy: Optional[ProxyConfig]

class TencentCaptchaOptions(TypedDict, total=False):
    siteUrl: str
    siteKey: str
    proxy: Optional[ProxyConfig]

class NetEaseCaptchaOptions(TypedDict, total=False):
    siteUrl: str
    siteKey: str
    jsLibUrl: Optional[str]
    apiServerSubdomain: Optional[str]
    userAgent: Optional[str]
    captchaId: Optional[str]
    captchaHash: Optional[str]
    captchaTimestamp: Optional[int]
    proxy: Optional[ProxyConfig]

class FaucetPayCaptchaOptions(TypedDict, total=False):
    siteUrl: str
    siteKey: str
    userAgent: Optional[str]
    proxy: Optional[ProxyConfig]

class CaptchaFoxOptions(TypedDict, total=False):
    siteUrl: str
    siteKey: str
    userAgent: Optional[str]
    proxy: Optional[ProxyConfig]

class AWSCaptchaOptions(TypedDict, total=False):
    siteUrl: str
    siteKey: str
    context: Optional[str]
    proxy: Optional[ProxyConfig]

class TextCaptchaImageOptions(TypedDict, total=False):
    siteUrl: str
    images: List[str]
    questionType: Optional[str]
    caseSensitive: Optional[bool]
    numeric: Optional[bool]
    minLength: Optional[int]
    maxLength: Optional[int]
    referenceImages: Optional[List[str]]

class RecaptchaImageOptions(TypedDict):
    siteUrl: str
    images: List[str]
    question: str
    questionType: str

class HCaptchaImageOptions(TypedDict):
    siteUrl: str
    images: List[str]
    question: str

class FunCaptchaImageOptions(TypedDict):
    siteUrl: str
    images: List[str]
    question: str

class GeeTestV3ImageOptions(TypedDict):
    siteUrl: str
    images: List[str]
    question: str

class GeeTestV4ImageOptions(TypedDict):
    siteUrl: str
    images: List[str]
    question: str

class RotateImageOptions(TypedDict, total=False):
    siteUrl: str
    images: List[str]
    question: Optional[str]
    angle: Optional[int]
    referenceImages: Optional[List[str]]

class SlideCaptchaImageOptions(TypedDict, total=False):
    siteUrl: str
    images: List[str]
    question: Optional[str]

class ClickCaptchaImageOptions(TypedDict, total=False):
    siteUrl: str
    images: List[str]
    question: str
    questionType: Optional[str]
    referenceImages: Optional[List[str]]

class GridCaptchaImageOptions(TypedDict, total=False):
    siteUrl: str
    images: List[str]
    question: str
    rows: Optional[int]
    columns: Optional[int]

class MultiSelectImageOptions(TypedDict, total=False):
    siteUrl: str
    images: List[str]
    question: str
    referenceImages: Optional[List[str]]

class DragCaptchaImageOptions(TypedDict, total=False):
    siteUrl: str
    images: List[str]
    question: str
    questionType: Optional[str]
    referenceImages: Optional[List[str]]

class MTCaptchaImageOptions(TypedDict, total=False):
    siteUrl: str
    images: List[str]
    module: Optional[str]
    maxLength: Optional[int]

class LeminCaptchaImageOptions(TypedDict):
    siteUrl: str
    images: List[str]
    question: str

class DataDomeCaptchaImageOptions(TypedDict, total=False):
    siteUrl: str
    images: List[str]
    question: Optional[str]

class CaptchaFoxImageOptions(TypedDict, total=False):
    siteUrl: str
    images: List[str]
    question: str
    questionType: Optional[str]
    referenceImages: Optional[List[str]]

class BinanceImageOptions(TypedDict, total=False):
    siteUrl: str
    images: List[str]
    question: str
    questionType: str
    referenceImages: Optional[List[str]]

class BLSImageOptions(TypedDict):
    siteUrl: str
    images: List[str]
    question: str

class TikTokImageOptions(TypedDict):
    siteUrl: str
    images: List[str]
    question: str

class ShopeeImageOptions(TypedDict):
    siteUrl: str
    images: List[str]
    question: str

class TemuCaptchaImageOptions(TypedDict):
    siteUrl: str
    images: List[str]

class TencentImageOptions(TypedDict):
    siteUrl: str
    images: List[str]
    question: str

class AWSWAFImageOptions(TypedDict):
    siteUrl: str
    images: List[str]
    question: str

class ProsopoImageOptions(TypedDict):
    siteUrl: str
    images: List[str]
    question: str

class FaucetPayImageOptions(TypedDict):
    siteUrl: str
    images: List[str]
    question: str



from setuptools import setup, find_packages

with open('README.md', 'r', encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='mydisct-solver',
    version='1.0.1',
    description='Official Python library for MyDisct Solver - Enterprise AI-Powered Captcha Solving Service with 20+ token types and 25+ image types',
    long_description=long_description,
    long_description_content_type='text/markdown',
    author='MyDisct Solver',
    author_email='support@solver.mydisct.com',
    url='https://github.com/mydisctsolver/MyDisct-Solver',
    project_urls={
        'Bug Tracker': 'https://github.com/mydisctsolver/MyDisct-Solver/issues',
        'Documentation': 'https://solver.mydisct.com/api-docs',
        'Homepage': 'https://solver.mydisct.com'
    },
    packages=find_packages(),
    install_requires=[
        'requests>=2.25.0'
    ],
    python_requires='>=3.7',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Security'
    ],
    keywords='captcha solver recaptcha hcaptcha turnstile funcaptcha geetest cloudflare mydisct automation bot bypass',
    license='MIT'
)



from .solver import MyDisctSolver
from .client import MyDisctClient
from .types import (
    ProxyConfig, Cookie, TaskResponse, AccountInfo,
    RecaptchaV2Options, RecaptchaV3Options, RecaptchaV2EnterpriseOptions,
    RecaptchaV3EnterpriseOptions, HCaptchaOptions, HCaptchaEnterpriseOptions,
    CloudflareTurnstileOptions, CloudflareTurnstileManagedOptions,
    CloudflareChallengeOptions, FunCaptchaOptions, GeeTestV4Options,
    MTCaptchaOptions, LeminCaptchaOptions, FriendlyCaptchaOptions,
    DataDomeOptions, AltchaOptions, TencentCaptchaOptions,
    NetEaseCaptchaOptions, FaucetPayCaptchaOptions, CaptchaFoxOptions,
    AWSCaptchaOptions, TextCaptchaImageOptions, RecaptchaImageOptions,
    HCaptchaImageOptions, FunCaptchaImageOptions, GeeTestV3ImageOptions,
    GeeTestV4ImageOptions, RotateImageOptions, SlideCaptchaImageOptions,
    ClickCaptchaImageOptions, GridCaptchaImageOptions, MultiSelectImageOptions,
    DragCaptchaImageOptions, MTCaptchaImageOptions, LeminCaptchaImageOptions,
    DataDomeCaptchaImageOptions, CaptchaFoxImageOptions, BinanceImageOptions,
    BLSImageOptions, TikTokImageOptions, ShopeeImageOptions,
    TemuCaptchaImageOptions, TencentImageOptions, AWSWAFImageOptions,
    ProsopoImageOptions, FaucetPayImageOptions
)

__version__ = '1.0.0'
__all__ = [
    'MyDisctSolver',
    'MyDisctClient',
    'ProxyConfig',
    'Cookie',
    'TaskResponse',
    'AccountInfo',
    'RecaptchaV2Options',
    'RecaptchaV3Options',
    'RecaptchaV2EnterpriseOptions',
    'RecaptchaV3EnterpriseOptions',
    'HCaptchaOptions',
    'HCaptchaEnterpriseOptions',
    'CloudflareTurnstileOptions',
    'CloudflareTurnstileManagedOptions',
    'CloudflareChallengeOptions',
    'FunCaptchaOptions',
    'GeeTestV4Options',
    'MTCaptchaOptions',
    'LeminCaptchaOptions',
    'FriendlyCaptchaOptions',
    'DataDomeOptions',
    'AltchaOptions',
    'TencentCaptchaOptions',
    'NetEaseCaptchaOptions',
    'FaucetPayCaptchaOptions',
    'CaptchaFoxOptions',
    'AWSCaptchaOptions',
    'TextCaptchaImageOptions',
    'RecaptchaImageOptions',
    'HCaptchaImageOptions',
    'FunCaptchaImageOptions',
    'GeeTestV3ImageOptions',
    'GeeTestV4ImageOptions',
    'RotateImageOptions',
    'SlideCaptchaImageOptions',
    'ClickCaptchaImageOptions',
    'GridCaptchaImageOptions',
    'MultiSelectImageOptions',
    'DragCaptchaImageOptions',
    'MTCaptchaImageOptions',
    'LeminCaptchaImageOptions',
    'DataDomeCaptchaImageOptions',
    'CaptchaFoxImageOptions',
    'BinanceImageOptions',
    'BLSImageOptions',
    'TikTokImageOptions',
    'ShopeeImageOptions',
    'TemuCaptchaImageOptions',
    'TencentImageOptions',
    'AWSWAFImageOptions',
    'ProsopoImageOptions',
    'FaucetPayImageOptions'
]
